Enum amazon_sp_fba_small_and_light::models::small_and_light_eligibility_status::SmallAndLightEligibilityStatus
source · [−]pub enum SmallAndLightEligibilityStatus {
ELIGIBLE,
NOTELIGIBLE,
}Expand description
SmallAndLightEligibilityStatus : The Small and Light eligibility status of the item. The Small and Light eligibility status of the item.
Variants
ELIGIBLE
NOTELIGIBLE